@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::AdGroup;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -16,7 +16,10 @@ sub _user_setable_attributes {
     return ( qw/ 
                  ID
                  accountID
+                 adOptimization
                  buyType
+                 createTimestamp
+                 lastUpdateTimestamp
                  name
                  nonGuaranteedSettings
                  orderID
@@ -26,8 +29,6 @@ sub _user_setable_attributes {
 
 sub _read_only_attributes {
     return ( qw/
-                 createTimestamp
-                 lastUpdateTimestamp
            / );
 }
 
@@ -39,7 +40,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -56,7 +57,10 @@ Creates a new instance
 
     ID
     accountID
+    adOptimization
     buyType
+    createTimestamp
+    lastUpdateTimestamp
     name
     nonGuaranteedSettings
     orderID
@@ -68,8 +72,6 @@ Creates a new instance
 
 =over 8
 
-    createTimestamp
-    lastUpdateTimestamp
 
 =back
 
