@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::SalesTeamMember;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -15,6 +15,7 @@ Yahoo::Marketing::APT::SalesTeamMember - a data object to represent a SalesTeamM
 sub _user_setable_attributes {
     return ( qw/ 
                  commissionPercentage
+                 orderCreator
                  primary
                  userID
             /  );
@@ -33,7 +34,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -49,6 +50,7 @@ Creates a new instance
 =over 8
 
     commissionPercentage
+    orderCreator
     primary
     userID
 
