@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::TargetingAttributeValue;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -19,7 +19,6 @@ sub _user_setable_attributes {
                  name
                  parentID
                  type
-                 value
             /  );
 }
 
@@ -36,7 +35,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -56,7 +55,6 @@ Creates a new instance
     name
     parentID
     type
-    value
 
 =back
 
